

set -ex



test -f "${SP_DIR}"/poetry_plugin_export/__init__.py
pip show poetry-plugin-export | rg -F "Version: 1.3.0"
pip check | rg -F "requires poetry, which is not installed."
! pip check | grep -Fv 'requires poetry, which is not installed.'
exit 0
